aboutsummaryrefslogtreecommitdiff
path: root/gcc/cfgloop.h
diff options
context:
space:
mode:
authorZdenek Dvorak <dvorakz@suse.cz>2006-12-11 00:34:20 +0100
committerZdenek Dvorak <rakdver@gcc.gnu.org>2006-12-10 23:34:20 +0000
commita14865dbe011d40552b95f646dd4172a81188601 (patch)
tree49e4518b80f9f2c4c2ddf2edcbb93a2d6e48c84d /gcc/cfgloop.h
parentc7463db95a98bc9b4372e2ab77df993f5dddd337 (diff)
downloadgcc-a14865dbe011d40552b95f646dd4172a81188601.zip
gcc-a14865dbe011d40552b95f646dd4172a81188601.tar.gz
gcc-a14865dbe011d40552b95f646dd4172a81188601.tar.bz2
loop.texi: Document number_of_latch_executions and number_of_cond_exit_executions.
* doc/loop.texi: Document number_of_latch_executions and number_of_cond_exit_executions. * tree-scalar-evolution.c (compute_overall_effect_of_inner_loop, chrec_is_positive, number_of_iterations_for_all_loops, scev_const_prop): Use number_of_latch_executions. (set_nb_iterations_in_loop): Do not increase the value of the number of iterations. (number_of_iterations_in_loop): Renamed to ... (number_of_latch_executions): ... this. (number_of_exit_cond_executions): New function. * tree-scalar-evolution.h (number_of_iterations_in_loop): Declaration removed. (number_of_latch_executions, number_of_exit_cond_executions): Declare. * tree-ssa-loop-ivcanon.c (canonicalize_loop_induction_variables): Use number_of_latch_executions. * tree-data-ref.c (get_number_of_iters_for_loop): Use number_of_exit_cond_executions. * tree-vect-analyze.c (vect_get_loop_niters): Ditto. * cfgloop.h (struct loop): Improve description of the nb_iterations field. * gcc.dg/tree-ssa/loop-17.c: Update outcome. From-SVN: r119718
Diffstat (limited to 'gcc/cfgloop.h')
-rw-r--r--gcc/cfgloop.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc/cfgloop.h b/gcc/cfgloop.h
index d523acf..4a13a6a 100644
--- a/gcc/cfgloop.h
+++ b/gcc/cfgloop.h
@@ -119,10 +119,10 @@ struct loop
/* Auxiliary info specific to a pass. */
void *aux;
/* The probable number of times the loop is executed at runtime.
This is an INTEGER_CST or an expression containing symbolic
names. Don't access this field directly:
- number_of_iterations_in_loop computes and caches the computed
+ number_of_latch_executions computes and caches the computed
information in this field. */
tree nb_iterations;
@@ -119,10 +119,10 @@ struct loop
/* Auxiliary info specific to a pass. */
void *aux;
- /* The probable number of times the loop is executed at runtime.
+ /* The number of times the latch of the loop is executed.
This is an INTEGER_CST or an expression containing symbolic
names. Don't access this field directly: